@@ -61,10 +61,6 @@ CONFIG cf_identify[] = {
 CONFIG cf_options[] = {
 #if !__MSDOS__
   { cft_strg, "append",		NULL,		NULL,NULL },
-/*#ifdef LCF_ATARAID*/
-#if 0
-  { cft_flag, "ataraid",	NULL,		NULL,NULL },
-#endif
   { cft_strg, "backup",		NULL,		NULL,NULL },
   { cft_strg, "bios-passes-dl",	NULL,		NULL,NULL },
   { cft_strg, "bitmap",		NULL,		NULL,NULL },
@@ -102,6 +98,10 @@ CONFIG cf_options[] = {
   { cft_strg, "menu-scheme",	NULL,		NULL,NULL },
   { cft_strg, "menu-title",	NULL,		NULL,NULL },
   { cft_strg, "message",	NULL,		NULL,NULL },
+#ifdef LCF_NOKEYBOARD
+  { cft_strg, "nokbdefault",	NULL,		NULL,NULL },
+#endif
+  { cft_flag, "noraid",		NULL,		NULL,NULL },
   { cft_flag, "nowarn",		NULL,		NULL,NULL },
   { cft_flag, "optional",	NULL,		NULL,NULL },
   { cft_strg, "password",	NULL,		NULL,NULL },
@@ -136,6 +136,9 @@ CONFIG cf_all[] = {
   { cft_strg, "literal",	NULL,		NULL,NULL },
   { cft_flag, "lock",		NULL,		NULL,NULL },
   { cft_flag, "mandatory",	NULL,		NULL,NULL },
+#ifdef LCF_NOKEYBOARD
+  { cft_flag, "nokbdisable",	NULL,		NULL,NULL },
+#endif
   { cft_flag, "optional",	NULL,		NULL,NULL },
   { cft_strg, "password",	NULL,		NULL,NULL },
   { cft_flag, "restricted",	NULL,		NULL,NULL },
@@ -251,7 +254,7 @@ int cfg_open(char *name)
 #if !__MSDOS__
 		die("Cannot open: %s", name);
 #else  /* __MSDOS__ */
-		fprintf(errstd,"No configuration file: %s\n", name);
+		warn("No configuration file: %s\n", name);
 		return -1;
 #endif /* __MSDOS__ */
     }
@@ -492,7 +495,7 @@ static int cfg_do_set(CONFIG *table,char *item,char *value,int copy,
 		if (walk->context == context)
 		    cfg_error("Duplicate entry '%s'",walk->name);
 		else {
-		    fprintf(errstd,"Ignoring entry '%s'\n",walk->name);
+		    warn("Ignoring entry '%s'",walk->name);
 		    if (!copy) free(value);
 		    return 1;
 		}
@@ -625,10 +628,10 @@ FILE *cfg_pw_open(void)
 #if 1
     if (stat(file_name, &buf)) die("Cannot stat '%s'", file_name);
     conf = buf.st_mtime;
-    if (!stat(pw_file_name, &buf) && conf>buf.st_mtime && !nowarn && !passw) {
-        fprintf(errstd,"Warning: '%s' more recent than '%s'\n",
-        	file_name, pw_file_name);
-        fprintf(errstd," Running 'lilo -p' is recommended.\n");
+    if (!stat(pw_file_name, &buf) && conf>buf.st_mtime && !passw) {
+        warn("'%s' more recent than '%s'\n"
+              "   Running 'lilo -p' is recommended.",
+              file_name, pw_file_name);
     }
 #endif    
 
@@ -652,9 +655,8 @@ FILE *cfg_pw_open(void)
     }
     if (!pw_file) die("Could not create '%s'", pw_file_name);
 #if 1
-    if (!stat(pw_file_name, &buf) && (buf.st_mode&0044) && !nowarn) {
-        fprintf(errstd,"Warning: '%s' readable by other than 'root'\n",
-        	pw_file_name);
+    if (!stat(pw_file_name, &buf) && (buf.st_mode&0044) ) {
+        warn("'%s' readable by other than 'root'", pw_file_name);
     }
 #endif    
     return pw_file;
