@@ -104,8 +104,9 @@ int raid_setup(void)
     
     if (!(boot=cfg_get_strg(cf_options,"boot"))) {
 	boot = "/";
-	if (!nowarn)
-	   fprintf(errstd,"Warning: RAID1 install implied by omitted 'boot='\n");
+#if 0
+      warn("RAID1 install implied by omitted 'boot='");
+#endif
     }
     if (stat(boot,&st)<0) die("raid_setup: stat(\"%s\")", boot);
 
@@ -120,10 +121,13 @@ int raid_setup(void)
     if ( MAJOR(st.st_rdev) != MAJOR_MD ) {	/* not raid */
 	if (cfg_get_strg(cf_options, RAID_EXTRA_BOOT))
 	    die("Not a RAID install, '" RAID_EXTRA_BOOT "=' not allowed");
-	return 0L;
+	return 0;
     }
     else {	/* It is a RAID installation */
 
+	if (!nowarn && boot[0]=='/' && !boot[1])
+	   warn("RAID1 install implied by 'boot=/'\n");
+	   
 /* scan the devices in /proc/partitions */
 	pf_hard_disk_scan();
 
@@ -155,7 +159,7 @@ int raid_setup(void)
 	if (!linear && !lba32) {
 	    lba32 = 1;
 	    if (!nowarn)
-		fprintf(errstd,"Warning: RAID install requires LBA32 or LINEAR;"
+		warn("RAID install requires LBA32 or LINEAR;"
 			" LBA32 assumed.\n");
 	}
 	extrap = cfg_get_strg(cf_options, RAID_EXTRA_BOOT);
@@ -202,7 +206,14 @@ int raid_setup(void)
 	}
 
     /* scan through all the RAID devices */
-	raid_limit = md_array_info.raid_disks + md_array_info.spare_disks;
+	raid_limit = md_array_info.raid_disks;
+	if (md_array_info.active_disks < md_array_info.raid_disks) {
+	    if (!force_raid) die("Not all RAID-1 disks are active; use '-H' to install to active disks only");
+	    else {
+		warn("Partial RAID-1 install on active disks only; booting is not failsafe\n");
+		raid_limit = md_array_info.active_disks;
+	    }
+	}
 	raid_index = 0;
    	for (pass=0; pass < raid_limit; pass++) {
 	    DEVICE dev;
@@ -224,8 +235,7 @@ int raid_setup(void)
             if(verbose>=3) printf("md: RAIDset device %d = 0x%04X\n", pass, device);	    
 	    if (device == 0) { /* empty slot left over from recovery process */
 		faulty++;
-	        if (!nowarn)
-		    fprintf(errstd,"Warning: Faulty disk in RAID-1 array; boot with caution!!\n");
+		warn("Faulty disk in RAID-1 array; boot with caution!!");
 		continue;
 	    }
 	    disk_fd = dev_open(&dev,device,O_NOACCESS);
@@ -411,15 +421,7 @@ int raid_setup(void)
 	}
 
 	if (raid_flags & FLAG_RAID_NOWRITE) {
-	    if (!nowarn) {
-		fprintf(errstd, "\nWarning: FLAG_RAID_NOWRITE has been set.\n");
-#if 0
-		if (verbose >= 1)
-		fprintf(errstd,   "  The boot loader will be unable to update the stored command line;\n"
-		                  "  'lock' and 'fallback' are not operable; the 'lilo -R' boot command\n"
-		                  "  line will be locked.\n\n");
-#endif
-	    }
+	    warn("FLAG_RAID_NOWRITE has been set.");
 	}
 #endif
 
@@ -451,11 +453,11 @@ int raid_setup(void)
 	}
 #endif
 	
-	if (!nowarn  &&  bios_passes_dl==DL_GOOD  &&  !(extra == X_MBR_ONLY || extra == X_MBR))
-	    fprintf(errstd, "Warning: Boot sector on  %s  will depend upon the BIOS device code\n"
-			    "  passed in the DL register being accurate.  Install Master Boot Records\n"
-			    "  with the 'lilo -M' command, and activate the RAID1 partitions with the\n"
-			    "  'lilo -A' command.\n",
+	if (bios_passes_dl==DL_GOOD  &&  !(extra == X_MBR_ONLY || extra == X_MBR))
+	    warn("Boot sector on  %s  will depend upon the BIOS device code\n"
+		"  passed in the DL register being accurate.  Install Master Boot Records\n"
+		"  with the 'lilo -M' command, and activate the RAID1 partitions with the\n"
+		"  'lilo -A' command.",
 		boot );
 	
 	return raid_offset[pri_index];
@@ -517,7 +519,7 @@ void raid_final(void)
 	{
 	  if (test) {
 	    bsect_cancel();
-	    if (passw) fprintf(errstd,"The password crc file has *NOT* been updated.\n");
+	    if (passw) printf("The password crc file has *NOT* been updated.\n");
 	    printf("The map file has *NOT* been updated.\n");
 	  }
 	  else {
@@ -568,13 +570,13 @@ void raid_final(void)
 							cp, force, 1, mask);
 			printf("The Master boot record of  %s  has%s been updated.\n",
 					raid_mbr[pass], (test ? " *NOT*" : ""));
-		    } else if (!nowarn) {
-			fprintf(errstd, "Warning:  %splicit AUTO does not allow updating the Master Boot Record\n"
-				        "  of '%s' on BIOS device code 0x80, the System Master Boot Record.\n"
-				        "  You must explicitly specify updating of this boot sector with\n"
-				        "  '-x %s' or 'raid-extra-boot = %s' in the\n"
-				        "  configuration file.\n",
-			cfg_get_strg(cf_options, RAID_EXTRA_BOOT) ? "Ex" : "Im",
+		    } else {
+			warn("%splicit AUTO does not allow updating the Master Boot Record\n"
+				"  of '%s' on BIOS device code 0x80, the System Master Boot Record.\n"
+				"  You must explicitly specify updating of this boot sector with\n"
+				"  '-x %s' or 'raid-extra-boot = %s' in the\n"
+				"  configuration file.",
+                                cfg_get_strg(cf_options, RAID_EXTRA_BOOT) ? "Ex" : "Im",
 				raid_mbr[pass],
 				raid_mbr[pass],
 				raid_mbr[pass] 
@@ -588,13 +590,10 @@ void raid_final(void)
 
 #ifdef FLAG_RAID_NOWRITE
     if (raid_flags & FLAG_RAID_NOWRITE) {
-	if (!nowarn) {
-		fprintf(errstd, "Warning: FLAG_RAID_NOWRITE has been set.\n");
-		if (verbose >= 1)
-		fprintf(errstd,   "  The boot loader will be unable to update the stored command line;\n"
-		                  "  'lock' and 'fallback' are not operable; the 'lilo -R' boot command\n"
-		                  "  line will be locked.\n\n");
-	}
+	warn("FLAG_RAID_NOWRITE has been set.%s", verbose>=1 ?
+	        "\n  The boot loader will be unable to update the stored command line;\n"
+	        "  'lock' and 'fallback' are not operable; the 'lilo -R' boot command\n"
+	        "  line will be locked." : "" );
     }
 #endif
 
